Learn R Programming

nlmixr2extra (version 5.0.0)

addCatCovariates: Make dummy variable cols and updated covarsVec

Description

Make dummy variable cols and updated covarsVec

Usage

addCatCovariates(data, covarsVec, catcovarsVec)

Value

return updated Data along with the updated covarsVec

Arguments

data

data frame used in the analysis

covarsVec

character vector of covariates that need to be added

catcovarsVec

character vector of categorical covariates that need to be added

Author

Vishal Sarsani