Skip to contents

Detect if a fit has any parameter at the boundary

Usage

isBoundaryFit(object)

Arguments

object

A model fit to check

Value

TRUE if the fit is an nlmxir2 fit and it has a parameter at the boundary; FALSE otherwise