Skip to contents

Plot a multistart result

Usage

# S3 method for class 'nlmixr2Multistart'
plot(x, type = c("waterfall", "parameters"), kBest = 20L, dOfvMax = NULL, ...)

Arguments

x

A nlmixr2Multistart object from multistart()

type

"waterfall" plots each start's objective function relative to the best one, worst to best; "parameters" plots how each parameter estimate varies across the best starts.

kBest

Number of starts to show in the "parameters" plot

dOfvMax

Upper limit for the waterfall's objective-function axis, for zooming in when one start is far worse than the rest

...

ignored

Value

A ggplot2 object

See also