Learn R Programming

nlmixr2extra (version 5.0.0)

profileNlmixr2FitCoreRet: Give the output data.frame for a single model for profile.nlmixr2FitCore

Description

Give the output data.frame for a single model for profile.nlmixr2FitCore

Usage

profileNlmixr2FitCoreRet(fitted, which, fixedVal)

Value

A data.frame with columns named "Parameter" (the parameter name(s) that were fixed), OFV (the objective function value), and the current estimate for each of the parameters. Omega values are given as their variances and covariances.

Arguments

fitted

The fit model

which

The parameter names to perform likelihood profiling on (NULL indicates all parameters)

fixedVal

The value that which is fixed to in case the model does not converge.

See Also

Other Profiling: fixedControl(), llpControl(), profile.nlmixr2FitCore(), profileFixed(), profileLlp()