This function is to set the number of threads to 2
Source:R/aaaNlmixr2ExtraCRAN.R
aaaNlmixr2ExtraCRAN.RdIn general it is a CRAN requirement that packages not use more than 2 threads. This function is to set the number of threads to 2 for CRAN testing. It is not intended for general use.