Expand parameters to include their covariate representations, if applicable.
Source:R/nlmixrFormula.R
dot-nlmixrFormulaExpandStartParam.RdExpand parameters to include their covariate representations, if applicable.
Usage
.nlmixrFormulaExpandStartParam(start, param, paramLink = NULL, data)
.nlmixrFormulaExpandStartParamSingle(
startName,
startValue,
param = NULL,
link = NULL,
data = NULL
)Arguments
- start
the starting values for the model
- param
The parameter in the model
- paramLink
Named character vector giving the link function for each parameter that has a
paramentry. Recognised values:"identity"(default) emits<param> <- <linear combination>;"log"wraps the linear combination inexp().- data
The dataset
- startName
The base name for the parameter
- startValue
The initial value for the base parameter
- link
Optional link function for this parameter (
"identity"or"log"). Defaults to"identity".