Parse the random effects part of a formula
Source:R/nlmixrFormula.R
dot-nlmixrFormulaParserRanef.RdParse the random effects part of a formula
Value
An unnamed list with one element per random effect. The elements each have names of "ranefVar", "ranefGroup", and "start" indicating the variable with the random effect, the grouping variable for the random effect, and the starting value for the standard deviation of the random effect.
Examples
if (FALSE) { # \dontrun{
.nlmixrFormulaParserRanef(str2lang("(c|id)+(d|id2)"))
} # }