If newName already exists in data and would be overwritten with
a different source column, this is treated as a hard error so that user data
is never silently clobbered.
Examples
if (FALSE) { # \dontrun{
.renameOrOverwrite(data.frame(A=1), newName="B", oldName="A")
} # }