R/AICHelpers.R
isBoundaryFit.Rd
Detect if a fit has any parameter at the boundary
isBoundaryFit(object)
A model fit to check
TRUE if the fit is an nlmxir2 fit and it has a parameter at the boundary; FALSE otherwise
TRUE
FALSE