Plot a multistart result
Arguments
- x
A
nlmixr2Multistartobject frommultistart()- type
"waterfall"plots each start's objective function relative to the best one, worst to best;"parameters"plots how each parameter estimate varies across the best starts.- kBest
Number of starts to show in the
"parameters"plot- dOfvMax
Upper limit for the waterfall's objective-function axis, for zooming in when one start is far worse than the rest
- ...
ignored
See also
Other Multistart:
multistart(),
multistartControl()