if (FALSE) {
# Likelihood profiling takes a long time to run each model multiple times, so
# be aware that running this example may take a few minutes.
oneCmt <- function() {
ini({
tka <- log(1.57)
tcl <- log(2.72)
tv <- fixed(log(31.5))
eta.ka ~ 0.6
add.sd <- 0.7
})
model({
ka <- exp(tka + eta.ka)
cl <- exp(tcl)
v <- exp(tv)
cp <- linCmt()
cp ~ add(add.sd)
})
}
fit <-
nlmixr2(
oneCmt, data = nlmixr2data::theo_sd, est="focei", control = list(print=0)
)
# profile all parameters
profall <- profile(fit)
# profile a single parameter
proftka <- profile(fit, which = "tka")
}
Run the code above in your browser using DataLab