Give the output data.frame for a single model for profile.nlmixr2FitCore
profileNlmixr2FitCoreRet(fitted, which, fixedVal)A data.frame with columns named "Parameter" (the parameter name(s) that were fixed), OFV (the objective function value), and the current estimate for each of the parameters. Omega values are given as their variances and covariances.
The fit model
The parameter names to perform likelihood profiling on
(NULL indicates all parameters)
The value that which is fixed to in case the model does not
converge.
Other Profiling:
fixedControl(),
llpControl(),
profile.nlmixr2FitCore(),
profileFixed(),
profileLlp()